==> 0.0.36.tar.gz: lib/src/widgets/story_video_widget.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:ocg_story/src/widgets/story_widget.dart';
import 'package:video_player/video_player.dart';

class StoryVideoWidget extends StatefulWidget {
  final String url;
  final StoryAssetType type;
  final Function(
    bool isLoaded,
    VideoPlayerController controller,
  ) onLoaded;
  final Function() onCompleted;

  const StoryVideoWidget({
    Key key,
    @required this.url,
    @required this.onLoaded,
    @required this.onCompleted,
    this.type = StoryAssetType.Network,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _StoryVideoWidgetState();
}

class _StoryVideoWidgetState extends State<StoryVideoWidget>
    with TickerProviderStateMixin<StoryVideoWidget>, WidgetsBindingObserver {
  VideoPlayerController _controller;
  double width, height;
  int lastTime;
  bool playingFirst;

  @override
  void initState() {
    super.initState();
    lastTime = DateTime.now().millisecondsSinceEpoch;
    playingFirst = true;
    WidgetsBinding.instance.addPostFrameCallback((duration) {
      if (mounted) {
        initialize();
        width = MediaQuery.of(context).size.height;
        height = MediaQuery.of(context).size.width;
      }
    });
  }

  @override
  void didChangeMetrics() {
    if (mounted) {}
  }

  initialize() {
    widget.onLoaded(false, null);
    switch (widget.type) {
      case StoryAssetType.File:
        _controller = VideoPlayerController.file(File(widget.url));
        break;
      case StoryAssetType.Network:
        _controller = VideoPlayerController.network(widget.url);
        break;
      case StoryAssetType.Asset:
        _controller = VideoPlayerController.asset(widget.url);
        break;
      default:
    }
    _controller.setLooping(true);
    _controller.initialize().then((_) async {
      await widget.onLoaded(
        true,
        _controller,
      );
      if (mounted) setState(() {});
      _controller.setVolume(0);
      _controller.play();
    });
    _controller.addListener(() {
      if (_controller.value.hasError) {
        widget.onCompleted();
      } else if (_controller.value.position == _controller.value.duration) {
        log("Completed");
        widget.onCompleted();
      }
    });
  }

  @override
  void didUpdateWidget(StoryVideoWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.url != widget.url) {
      reinitialize();
    }
  }

  void reinitialize() {
    if (_controller != null && widget.url != _controller.dataSource) {
      _controller.dispose();
      _controller = null;
      initialize();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
      color: Colors.black,
      child: Container(
        child: _controller != null &&
                _controller.value.initialized &&
                height != null &&
                width != null
            ? SizedBox(
                height: _controller.value.size?.height ?? 0,
                child: VideoPlayer(
                  _controller,
                ),
              )
            : Center(
                child: CircularProgressIndicator(),
              ),
      ),
    );
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    _controller?.dispose();
    super.dispose();
  }
}

==> 0.0.44.tar.gz: lib/src/widgets/story_video_widget.dart <==
import 'dart:developer';
import 'dart:io';

import 'package:flutter/material.dart';
import 'package:ocg_story/src/widgets/story_widget.dart';
import 'package:video_player/video_player.dart';

class StoryVideoWidget extends StatefulWidget {
  final String url;
  final StoryAssetType type;
  final VideoPlayerController controller;
  final Function(
    bool isLoaded,
    VideoPlayerController controller,
  ) onLoaded;
  final Function() onCompleted;

  const StoryVideoWidget({
    Key key,
    @required this.url,
    @required this.onLoaded,
    @required this.onCompleted,
    this.type = StoryAssetType.Network,
    this.controller,
  }) : super(key: key);

  @override
  State<StatefulWidget> createState() => _StoryVideoWidgetState();
}

class _StoryVideoWidgetState extends State<StoryVideoWidget>
    with TickerProviderStateMixin<StoryVideoWidget>, WidgetsBindingObserver {
  VideoPlayerController _controller;
  double width, height;
  int lastTime;
  bool playingFirst;

  @override
  void initState() {
    super.initState();
    lastTime = DateTime.now().millisecondsSinceEpoch;
    playingFirst = true;
    WidgetsBinding.instance.addPostFrameCallback((duration) {
      if (mounted) {
        initialize();
        width = MediaQuery.of(context).size.height;
        height = MediaQuery.of(context).size.width;
      }
    });
  }

  @override
  void didChangeMetrics() {
    if (mounted) {}
  }

  initialize() {
    widget.onLoaded(false, null);
    if (widget.controller == null) {
      switch (widget.type) {
        case StoryAssetType.File:
          _controller = VideoPlayerController.file(File(widget.url));
          break;
        case StoryAssetType.Network:
          _controller = VideoPlayerController.network(widget.url);
          break;
        case StoryAssetType.Asset:
          _controller = VideoPlayerController.asset(widget.url);
          break;
        default:
      }
      _controller.setLooping(true);
      _controller.initialize().then((_) async {
        await widget.onLoaded(
          true,
          _controller,
        );
        if (mounted) setState(() {});
        // _controller.setVolume(0);
        _controller.play();
      });
      _controller.addListener(() {
        if (_controller.value.hasError) {
          widget.onCompleted();
        } else if (_controller.value.position == _controller.value.duration) {
          log("Completed");
          widget.onCompleted();
        }
      });
    }
  }

  @override
  void didUpdateWidget(StoryVideoWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (oldWidget.url != widget.url) {
      reinitialize();
    }
  }

  void reinitialize() {
    if (_controller != null && widget.url != _controller.dataSource) {
      _controller.dispose();
      _controller = null;
      initialize();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
      color: Colors.black,
      child: Container(
        child: _controller != null &&
                _controller.value.initialized &&
                height != null &&
                width != null
            ? SizedBox(
                height: _controller.value.size?.height ?? 0,
                child: VideoPlayer(
                  _controller,
                ),
              )
            : Center(
                child: CircularProgressIndicator(),
              ),
      ),
    );
  }

  @override
  void dispose() {
    WidgetsBinding.instance.removeObserver(this);
    if (widget.controller == null) {
      _controller?.dispose();
    }
    super.dispose();
  }
}
